@@ -24,14 +24,12 @@ from .models.routes import (
     Route,
     RedirectRoute
 )
-from .models.request import (
-    Headers,
-    Request,
-    File,
-    FieldStorage,
-    Field,
-    request
-)
+
+from .models.request import Request
+from .models.field import Field
+from .models.file import File
+from .models.field_storage import FieldStorage
+from .models.headers import Headers
 
 # pyweber events
 from .core.events import (
@@ -58,7 +56,21 @@ from .utils.types import (
     WebSocketStatusCode,
     WindowEventType,
     Icons,
-    GetBy
+    GetBy,
+    DateFormat,
+    DateTimeFormat,
+    PasswordFormat,
+    ByteFormat,
+    EmailFormat,
+    UuidFormat,
+    UrlFormat,
+    HostnameFormat,
+    Ipv4Format,
+    Ipv6Format,
+    Int32Format,
+    Int64Format,
+    FloatFormat,
+    DoubleFormnat
 )
 from .utils.exceptions import (
     InvalidRouteFormatError,
@@ -101,6 +113,14 @@ from .components.input import (
     InputUrl
 )
 
+def session_id() -> str | None: # pragma: no cover
+    PrintLine(text='This is an experimental feature', level='WARNING')
+    return window.session_storage.get('_pyweber_sessionId', None)
+
+def session(): # pragma: no cover
+    PrintLine(text='This is an experimental feature', level='WARNING')
+    return sessions.get_session(session_id())
+
 __all__ = [
     'Template',
     'Pyweber',
@@ -113,13 +133,14 @@ __all__ = [
     'FieldStorage',
     'Field',
     'Request',
-    'request',
     'Response',
     'TemplateEvents',
     'WindowEvents',
     'EventHandler',
     'Element',
     'sessions',
+    'session',
+    'session_id',
     'window',
     'config',
     'Colors',
@@ -131,6 +152,20 @@ __all__ = [
     'HTMLTag',
     'GetBy',
     'Icons',
+    'DateFormat',
+    'DateTimeFormat',
+    'PasswordFormat',
+    'ByteFormat',
+    'EmailFormat',
+    'UuidFormat',
+    'UrlFormat',
+    'HostnameFormat',
+    'Ipv4Format',
+    'Ipv6Format',
+    'Int32Format',
+    'Int64Format',
+    'FloatFormat',
+    'DoubleFormnat',
     'HTTPStatusCode',
     'JWTAlgorithms',
     'NonSelfClosingHTMLTags',
