@@ -11,10 +11,10 @@ from pyweber.models.request import Request, ClientInfo
 from pyweber.utils.utils import PrintLine, Colors
 from typing import TYPE_CHECKING, Callable
 
-if TYPE_CHECKING:
+if TYPE_CHECKING: # pragma: no cover
     from pyweber.connection.websocket import TaskManager
 
-class HttpServer:
+class HttpServer: # pragma: no cover
     def __init__(self, update_handler: Callable):
         self.connections: list[socket.socket] = []
         self.route, self.port, self.host = None, None, None
@@ -175,7 +175,7 @@ class HttpServer:
                                     ).start()
                         
                     except KeyboardInterrupt:
-                        shutil.rmtree('__pycache__', ignore_errors=True)
+                        self.clear_cache(path='.')
                         PrintLine(text='Server offline')
                         break
         
@@ -186,6 +186,11 @@ class HttpServer:
             except Exception as e:
                 PrintLine(text=f'Error [server] 1: {e}', level='ERROR')
                 raise e
+    
+    def clear_cache(self, path: str = '.'):
+        for root, folders, files in os.walk(top=path):
+            if any(p in root for p in ['__pycache__', 'tests/config', '.pyweber']):
+                shutil.rmtree(path=root, ignore_errors=True)
             
     def run(self, route: str, port: int, host: str, cert_file: str, key_file: str):
         self.route, self.port, self.host = route, port, host
