@@ -3,23 +3,31 @@ import asyncio
 import hashlib
 from time import time
 from watchdog.observers import Observer
-from typing import Union, Callable, Awaitable
+from typing import Callable, Awaitable
 from watchdog.events import FileSystemEventHandler
 
 from pyweber.utils.utils import Colors, PrintLine
 
-class ReloadServer:
-    def __init__(self, ws_reload: Callable[..., Awaitable], http_reload: Callable, watch_path: str = '.'):
+class ReloadServer: # pragma: no cover
+    def __init__(
+            self,
+            ws_reload: Callable[..., Awaitable],
+            http_reload: Callable,
+            watch_path: str = '.',
+            extension_files: list[str] = [],
+            ignore_reload_time: float = 10
+        ):
+        assert callable(ws_reload) and callable(http_reload)
         self.ws_reload = ws_reload
         self.http_reload = http_reload
         self.watch_path = watch_path
-        self.watch_file_extensions: list[str] = ['.css', '.html', '.js', '.py']
-        self.ignore_reload_time = 10
+        self.watch_file_extensions = extension_files
+        self.ignore_reload_time = ignore_reload_time
     
     def start(self):
         asyncio.run(WatchDogFiles(self).start())
 
-class WatchDogFiles:
+class WatchDogFiles: # pragma: no cover
     def __init__(self, reload_server: ReloadServer):
         self.event_handler = ReloadHandler(reload_server)
         self.observer = Observer()
@@ -41,7 +49,7 @@ class WatchDogFiles:
         
         self.observer.join()
 
-class ReloadHandler(FileSystemEventHandler):
+class ReloadHandler(FileSystemEventHandler): # pragma: no cover
     def __init__(self, reload_server: ReloadServer):
         self.reload_server = reload_server
         self.start_server_time = time()
@@ -66,10 +74,14 @@ class ReloadHandler(FileSystemEventHandler):
 
             if new_hash and new_hash != old_hash:
                 PrintLine(text=f'♻  File {green}{os.path.basename(event.src_path)}{reset} modified. Reloading...')
-                PrintLine(text=f'♻  Restarting the server...')
-                self.reload_server.http_reload()
-                PrintLine(text=f'♻  Server restarted...')
+                self.restart_server(changed_file=event.src_path)
                 PrintLine(text=f'♻  Reloading client...')
 
                 asyncio.run(self.reload_server.ws_reload(data={'reload': True}, session_id=None))
-                self.hash_files[event.src_path] = new_hash
\ No newline at end of file
+                self.hash_files[event.src_path] = new_hash
+    
+    def restart_server(self, changed_file: str):
+        if changed_file.endswith('.py'):
+            PrintLine(text=f'♻  Restarting the server...')
+            self.reload_server.http_reload(changed_file)
+            PrintLine(text=f'♻  Server restarted...')
\ No newline at end of file
