@@ -1,18 +1,18 @@
 from typing import TYPE_CHECKING
 from time import time
 
-if TYPE_CHECKING:
+if TYPE_CHECKING: # pragma: no cover
     from pyweber.core.template import Template
     from pyweber.core.window import Window
 
-class Session:
+class Session: # pragma: no cover
     def __init__(self, template: 'Template', window: 'Window', session_id: str):
         self.template = template
         self.window = window
         self.session_id = session_id
         self.create_at = time()
 
-class SessionManager:
+class SessionManager: # pragma: no cover
     def __init__(self):
         self.__sessions: dict[str, Session] = {}
     
@@ -21,14 +21,15 @@ class SessionManager:
         return self.__sessions
 
     @property
-    def lenght(self):
+    def length(self):
         return len(self.sessions)
     
     @property
     def all_sessions(self):
         return list(self.sessions.keys())
     
-    def add_session(self, session_id: str, Session: Session):
+    def add_session(self, session_id: str, session: Session):
+        assert isinstance(session, Session)
         self.sessions[session_id] = Session
     
     def remove_session(self, session_id: str):
@@ -38,6 +39,9 @@ class SessionManager:
     def get_session(self, session_id: str):
         return self.sessions.get(session_id, None)
     
+    def __len__(self):
+        return len(self.sessions)
+    
     def __getitem__(self, session_id: str):
         return self.get_session(session_id=session_id)
 
