@@ -14,12 +14,12 @@ from pyweber.connection.session import sessions, Session
 from pyweber.models.template_diff import TemplateDiff
 from pyweber.models.task_manager import TaskManager
 
-if TYPE_CHECKING:
+if TYPE_CHECKING: # pragma: no cover
     from pyweber.pyweber.pyweber import Pyweber
     from pyweber.core.template import Template
     from pyweber.core.window import Window
 
-def need_message_keys():
+def need_message_keys(): # pragma: no cover
     return [
         'type',
         'event_ref',
@@ -34,7 +34,7 @@ def need_message_keys():
         'sessionId'
     ]
 
-class BaseWebsockets:
+class BaseWebsockets: # pragma: no cover
     def __init__(self, app: 'Pyweber', protocol: Literal['pyweber', 'uvicorn'] = 'pyweber'):
         self.protocol: Literal['pyweber', 'uvicorn'] = protocol
         self.task_manager = TaskManager()
@@ -135,7 +135,6 @@ class BaseWebsockets:
     
     async def get_template_diff(self, session_template: 'Template', route: str):
         diff = TemplateDiff()
-        new_template = await self.app.clone_template(route=route)
 
         for tag in ['head', 'body']:
             old_element = self.old_template.querySelector(tag)
@@ -144,15 +143,12 @@ class BaseWebsockets:
                 new_element=session_template.querySelector(tag),
                 old_element=old_element
             )
-
-            # diff.track_differences(
-            #     new_element=new_template.querySelector(tag),
-            #     old_element=old_element
-            # )
+        
+        self.old_template = session_template.clone()
         
         return diff.differences
 
-class WebSocket(BaseWebsockets):
+class WebSocket(BaseWebsockets): # pragma: no cover
     def __init__(self, app: 'Pyweber', protocol: Literal['pyweber', 'uvicorn'] = 'pyweber'):
         super().__init__(app=app, protocol=protocol)
     
@@ -164,7 +160,7 @@ class WebSocket(BaseWebsockets):
     def add_session(self, session_id: str, template: 'Template', window: 'Window'):
         sessions.add_session(
             session_id=session_id,
-            Session=Session(
+            session=Session(
                 template=template,
                 window=window,
                 session_id=session_id
@@ -309,7 +305,7 @@ class WebSocket(BaseWebsockets):
                 ssl_context = ssl.SSLContext(ssl.PROTOCOL_TLS_SERVER)
                 ssl_context.load_cert_chain(certfile=cert_file, keyfile=key_file)
             except Exception as e:
-                PrintLine(text=f"WebSocket SSL configuration failed: {e}", level='ERROR')
+                # PrintLine(text=f"WebSocket SSL configuration failed: {e}", level='ERROR')
                 raise e
             return ssl_context
         
@@ -317,21 +313,21 @@ class WebSocket(BaseWebsockets):
             if cert_file and key_file:
                 ssl_context = ssl_setup()
             
-            protocol = 'wss' if ssl_context else 'ws'
-            PrintLine(text=f"Server [ws] is running in {protocol}://{host}:{port}")
+            # protocol = 'wss' if ssl_context else 'ws'
+            # PrintLine(text=f"Server [ws] is running in {protocol}://{host}:{port}")
 
-            async with async_serve(self.ws_handler_wsgi, host=host, port=port, ssl=ssl_context) as server:
+            async with async_serve(self.ws_handler_wsgi, host=host, port=port, ssl=ssl_context, max_size=2**48, write_limit=2**48) as server:
                 await server.serve_forever()
 
         except Exception as e:
-            PrintLine(text=f'Websocket server error: {e}', level='ERROR')
+            # PrintLine(text=f'Websocket server error: {e}', level='ERROR')
             raise e
     
     async def __call__(self, scope, receive, send):
         assert scope.get('type', None) == 'websocket'
         await self.ws_handler_asgi(receive=receive, send=send)
 
-def event_is_running(message: wsMessage, task_manager: TaskManager) -> bool:
+def event_is_running(message: wsMessage, task_manager: TaskManager) -> bool: # pragma: no cover
     """Check if event is running"""
     if message.session_id in task_manager.active_handlers_async:
         template = sessions.get_session(session_id=message.session_id).template
