@@ -8,7 +8,7 @@ from pyweber.utils.loads import LoadStaticFiles
 from pyweber.config.config import config
 from pyweber.utils.types import HTTPStatusCode
 
-class Template:
+class Template: # pragma: no cover
     def __init__(self, template: str, status_code: int = 200, title: str = None, **kwargs):
         self.__template = self.__read_file(file_path=template)
         self.kwargs = kwargs
@@ -61,6 +61,15 @@ class Template:
 
             if title:
                 title.content = value if value else title.content
+    
+    @property
+    def head(self): return self.root.querySelector('head')
+    
+    @property
+    def body(self): return self.root.querySelector('body')
+
+    @property
+    def style(self): return self.root.querySelectorAll('style')[-1]
 
     def get_icon(self):
         return str(config['app'].get('icon'))
@@ -251,13 +260,18 @@ class Template:
         return content
 
     def __read_file(self, file_path: str) -> str:
+        from pyweber.models.error_pages import ErrorPages
         if file_path.endswith('.html'):
             path = os.path.join('templates', file_path) if not os.path.isfile(file_path) else file_path
             
-            if os.path.isfile(path=path):
+            try:
                 return LoadStaticFiles(path=path).load
-            else:
-                raise FileNotFoundError('The file not found, please include on templates file')
+            
+            except FileNotFoundError:
+                return ErrorPages().page_server_error.build_html().replace(
+                    "{{error}}",
+                    f'{path} not found, please include on templates file'
+                )
         
         return file_path
     
