@@ -9,7 +9,7 @@ from pyweber.core.element import Element
 from pyweber.core.template import Template
 from pyweber.models.request import Request
 from pyweber.models.response import Response
-from pyweber.utils.types import ContentTypes, StaticFilePath
+from pyweber.utils.types import ContentTypes, StaticFilePath, HTTPStatusCode
 from pyweber.utils.loads import LoadStaticFiles
 from pyweber.core.window import window
 
@@ -19,17 +19,22 @@ from pyweber.models.cookies import CookieManager
 from pyweber.models.routes import (
     Route,
     RedirectRoute,
-    RouteManager
+    RouteManager,
 )
 
+from pyweber.models.openapi import OpenApiProcessor
+
+from pyweber.utils.utils import PrintLine
+
 @dataclass
-class StateResult:
+class StateResult: # pragma: no cover
     template: Any
     status_code: int
     content_type: ContentTypes
     redirect_path: str
     process_response: bool
     kwargs: dict[str, Any]
+    callback: Callable[..., Any]
 
     def update(
         self,
@@ -38,6 +43,7 @@ class StateResult:
         content_type = None,
         redirect_path = None,
         process_response = None,
+        callback = None,
         kwargs = {}
     ):
         self.template = template if template else self.template
@@ -45,12 +51,13 @@ class StateResult:
         self.content_type = content_type if content_type else self.content_type
         self.redirect_path = redirect_path if redirect_path else self.redirect_path
         self.process_response = process_response if process_response is not None else self.process_response
+        self.callback = callback if callback is not None else self.callback
         self.kwargs = kwargs if kwargs else self.kwargs
 
         return self
 
 @dataclass
-class TemplateResult:
+class TemplateResult: # pragma: no cover
     status_code: int
     content_type: ContentTypes
     redirect_path: str
@@ -58,7 +65,7 @@ class TemplateResult:
     template: Union[Template, Element, dict, list, str]
 
 @dataclass
-class ContentResult:
+class ContentResult: # pragma: no cover
     content: bytes
     content_type: ContentTypes
 
@@ -74,7 +81,7 @@ class Pyweber(
     CookieManager,
     MiddlewareManager,
     RouteManager
-):
+): # pragma: no cover
     def __init__(self, **kwargs):
         MiddlewareManager.__init__(self)
         RouteManager.__init__(self)
@@ -95,6 +102,9 @@ class Pyweber(
         if not isinstance(request, Request):
             raise TypeError(f'request must be a Request instances, but got {type(request).__name__}')
         
+        if re.search(r'^/_pyweber/(?:.*?)/openapi.json$', request.path):
+            await self.__add_openapi_route()
+        
         _route, _ = self.resolve_path(route=request.path)
         title = None
 
@@ -116,6 +126,7 @@ class Pyweber(
                     process_response=before_request_response.process_response,
                     content_type=ContentTypes.html,
                     redirect_path=request.path,
+                    callback=None,
                     kwargs={}
                 )
             )
@@ -157,7 +168,7 @@ class Pyweber(
         process_response: bool = False
     ):
         if isinstance(template, Template):
-            return self._process_template_object(template=template, content_type=content_type)
+            return self._process_template_object(template=template, title=title, content_type=content_type)
         
         elif isinstance(template, Element):
             return self._process_element_object(
@@ -187,7 +198,8 @@ class Pyweber(
     def _process_json_object(self, template: Union[dict, list, set]):
         return ContentResult(content=json.dumps(template).encode(), content_type=ContentTypes.json)
     
-    def _process_template_object(self, template: Template, content_type: ContentTypes):
+    def _process_template_object(self, template: Template, title: str, content_type: ContentTypes):
+        template.title = title if title else template.title
         return ContentResult(content=template.build_html().encode(), content_type=content_type)
     
     def _process_element_object(
@@ -241,6 +253,7 @@ class Pyweber(
             content_type=ContentTypes.html,
             process_response=True,
             kwargs=kwargs,
+            callback=None,
             redirect_path=path
         )
 
@@ -258,7 +271,8 @@ class Pyweber(
                         redirect_path=self.build_route(_route.full_route, **kwargs),
                         template=_route.template,
                         process_response=_route.process_response,
-                        content_type=_route.content_type
+                        content_type=_route.content_type,
+                        callback=_route.callback
                     )
                 else:
                     state_result.update(
@@ -266,6 +280,7 @@ class Pyweber(
                         process_response=_route.process_response,
                         status_code=_route.status_code,
                         content_type=_route.content_type,
+                        callback=_route.callback,
                         kwargs=kwargs
                     )
                 
@@ -321,7 +336,7 @@ class Pyweber(
         state: StateResult,
         redirect_route: RedirectRoute,
         redirect_path: str,
-        kwargs
+        **kwargs
     ):
         if redirect_route.route.middlewares:
             middleware_result = await self.process_route_middleware(
@@ -330,11 +345,12 @@ class Pyweber(
                 status_code=redirect_route.status_code
             )
 
-            return state.update(
-                status_code=middleware_result.status_code,
-                process_response=middleware_result.process_response,
-                template=middleware_result.content
-            )
+            if middleware_result:
+                return state.update(
+                    status_code=middleware_result.status_code,
+                    process_response=middleware_result.process_response,
+                    template=middleware_result.content
+                )
         
         return state.update(
             template=redirect_route.route.template,
@@ -342,6 +358,7 @@ class Pyweber(
             content_type=redirect_route.route.content_type,
             redirect_path=redirect_path,
             process_response=redirect_route.route.process_response,
+            callback=redirect_route.route.callback,
             kwargs=redirect_route.kwargs or kwargs
         )
 
@@ -350,7 +367,13 @@ class Pyweber(
 
         while callable(template) or isinstance(template, RedirectRoute):
             if callable(template):
-                template = await template(**state_result.kwargs) if inspect.iscoroutinefunction(template) else template(**state_result.kwargs)
+                request_body = self.request.body if self.request else {}
+                kwargs = OpenApiProcessor.prepare_callback_kwargs(
+                    callback=state_result.callback,
+                    **{**state_result.kwargs, **request_body}
+                )
+
+                template = await template(**kwargs) if inspect.iscoroutinefunction(template) else template(**kwargs)
             
             if isinstance(template, RedirectRoute):
                 redirect_path = self.build_route(route=template.route.full_route, **state_result.kwargs)
@@ -360,7 +383,7 @@ class Pyweber(
                     state=state_result,
                     redirect_route=template,
                     redirect_path=redirect_path,
-                    kwargs=state_result.kwargs
+                    **state_result.kwargs
                 )
 
                 template = state_result.template
@@ -405,6 +428,11 @@ class Pyweber(
                     route='/admin',
                     template=str(StaticFilePath.admin_page.value)
                 ),
+                Route(
+                    route='/docs',
+                    template=str(StaticFilePath.pyweber_docs.value),
+                    title='Pyweber Documentation'
+                ),
                 Route(
                     route='/_pyweber/admin/{uuid}/.css',
                     template=str(StaticFilePath.admin_css_file.value),
@@ -433,6 +461,56 @@ class Pyweber(
             ]
         )
     
+    async def __add_openapi_route(self):
+        route = '/_pyweber/{uuid}/openapi.json'
+
+        if route not in self._RouteManager__routes:
+            self.add_group_routes([
+                Route(
+                    route=route,
+                    template=self.__get_routes(),
+                    content_type=ContentTypes.json
+                )
+            ])
+    
+    def __get_routes(self):
+        list_routes = [self.get_route_by_path(route) for route in self.list_routes if route not in ['/docs']]
+        schema = {
+            "openapi": "3.0.0",
+            "info": {
+                "title": "Pyweber Documentation",
+                "version": "1.0.0"
+            },
+            "paths": {}
+        }
+
+        for route in list_routes:
+            if isinstance(route, Route):
+                schema['paths'][route.route] = {}
+
+                for method in route.methods:
+                    schema['paths'][route.route][method.lower()] = {
+                        "summary": route.title or 'Pyweber Route',
+                        "parameters": [
+                            v for _, v in OpenApiProcessor.get_route_spec(route.route, route.callback).items()
+                        ],
+                        "responses": {
+                            str(route.status_code): {
+                                "description": HTTPStatusCode.search_name_by_code(route.status_code)
+                            },
+                            str(500): {
+                                'description': HTTPStatusCode.search_name_by_code(500)
+                            }
+                        }
+                    }
+
+                    request_body = OpenApiProcessor.get_body_spec(route.route, route.callback)
+
+                    if request_body.get('content') and route.callback.__name__ != '<lambda>':
+                        schema['paths'][route.route][method.lower()]['requestBody'] = request_body
+
+        return schema
+    
     async def clone_template(self, route: str):
         template_result = await self.get_template(route=route)
 
@@ -441,8 +519,8 @@ class Pyweber(
         
         return template_result.template.clone()
 
-    def update(self):
-        return self.__update_handler() if self.__update_handler else None
+    def update(self, changed_file: str = None):
+        return self.__update_handler(module=changed_file) if self.__update_handler else None
     
     def launch_url(self, url: str, new_page: bool = False):
         return webbrowser.open(url=url, new=new_page)
